import type { UnsignedRpcTransactionData } from './signing';
import type { WalletConnect } from './walletconnect';
import type { Wallets } from './wallets';
export declare namespace Transactions {
    interface Genesis {
        from: string;
        to: string;
        transferAmount: BigNumber;
        decimals: number;
    }
    type Direction = 'in' | 'out' | 'default';
    interface ExtraTxAttributes {
        custom_nonce?: number;
        custom_gas_limit?: number;
        token_id?: string;
        to_address_tag?: string[];
    }
    interface BigNumber {
        bigNumber: string;
        number: number;
        decimals?: number;
    }
    interface TransactionBlock {
        _id: string;
        hash: string;
        parentHash: string;
        number: number;
        timestamp: number;
        nonce: number;
        difficulty: number;
        miner: string;
        extraData: string;
        _difficulty: BigNumber;
        gasLimit: BigNumber;
        gasUsed: BigNumber;
    }
    interface TransactionCoin {
        from: string;
        to: string;
        transferAmount: BigNumber;
        decimals: number;
    }
    interface TransactionToken {
        _id: string;
        contractAddress: string;
        name: string;
        symbol: string;
        decimals: number;
        transferAmount: BigNumber;
        price?: number;
        image?: Wallets.Images;
        verified: -1 | 0 | 1 | 2;
    }
    interface TransactionFee {
        gasLimit: number;
        gasPrice: number;
        gasUsed: number;
    }
    interface Reward {
        rewardType: string;
        from: string;
        to: string;
        decimals: number;
        transferAmount: BigNumber;
    }
    interface TransactionHistory {
        hash: string;
        type: string;
        value: {
            bigNumber: BigNumber;
            number: number;
        };
        time: number;
        status: number;
        nonce: BigNumber;
        fee: {
            gasLimit: string;
            gasPrice: string;
        };
    }
    interface UserEvent {
        _id: string;
        logIndex: number;
        hash: string;
        chainId: string;
        tags: Array<string>;
        block: TransactionBlock;
        timestamp: number;
        related: Array<string>;
        status: number;
        genesis: Genesis;
        bip44: string;
        nft?: {
            contractAddress: string;
            name: string;
            nft: string;
            metadata?: {
                image?: string;
                attributes?: Array<Wallets.NFTAttribute>;
                name?: string;
                description?: string;
            };
            symbol: string;
            totalSupply: number | null;
            type: Wallets.NFTTypes;
            _id: string;
        };
        nftInstance?: {
            _id: string;
            instanceId: number;
            nft: string;
            lastOwner: string;
            metadata?: {
                image?: string;
                attributes?: Array<Wallets.NFTAttribute>;
                name?: string;
                description?: string;
            };
        };
        fee?: TransactionFee;
        ledger?: BigNumber;
        metadata: {
            chainid: string;
        };
        coin?: TransactionCoin;
        reward?: Reward;
        from: string;
        to: string;
        token?: {
            transferAmount: BigNumber;
            token: TransactionToken;
        };
        externalExplorerURL?: string;
        type: 'transfer' | 'fee' | 'action' | 'custom' | 'reward' | 'depositWeth' | 'withdrawWeth';
        transaction: {
            from: string;
            to: string;
            gasUsed?: BigNumber;
            gasLimit?: BigNumber;
            effectiveGasPrice?: BigNumber;
            gasPrice?: BigNumber;
            hash: string;
        };
    }
    interface SimplexEvent {
        event_id?: string;
        name?: string;
        payment?: {
            id: string;
            status: string;
            blockchain_txn_hash: string;
            crypto_total_amount: {
                amount: number;
                currency: string;
            };
            partner_end_user_id: string;
        };
    }
    type Context = SimplexEvent;
    type TxDataTypes = 'NFT' | 'TOKEN' | 'ERC20' | 'ERC721' | 'ERC1155' | 'SFT' | 'COIN' | 'CONTRACT';
    type ContractTransactionType = 'initiated' | 'external' | 'aag';
    interface UserTransaction {
        _id: string;
        type: 'unknown' | 'erc20' | 'nft' | 'erc1155' | 'erc1155batch' | 'coin' | 'swap' | 'addLiquidity' | 'removeLiquidity' | 'poolCreation' | 'pairCreation' | 'erc721' | 'contract' | 'cancel';
        hash: string;
        desc?: string;
        to: string;
        from: string;
        fee: {
            amount: string;
            gasLimit?: string;
            gasPrice?: string;
            gasUsed?: string;
            maxFeePerGas?: string;
            maxPriorityFeePerGas?: string;
            effectiveGasPrice: string;
        };
        nonce?: number | string;
        status: 0 | 1 | 2 | 3 | 4 | 5 | 6;
        chainId: string;
        bip44: string;
        time: number;
        confirmedOn?: number;
        func?: string;
        sourceUrl?: string;
        events: Array<UserEvent>;
        block: null;
        txData?: {
            id: number;
            jsonrpc: string;
            method: WalletConnect.EventName;
            url?: string;
            params?: UnsignedRpcTransactionData;
            object?: UnsignedRpcTransactionData;
        };
        tags?: string[];
        related: string[];
        externalExplorerURL?: string;
        aggregatedData?: {
            contractAddress: string;
            type: TxDataTypes;
            instanceId?: number;
            amount?: string;
            to: string;
            mainEvent?: Transactions.UserEvent;
            fromWallet: Wallets.UserWallet;
            toWallet: Wallets.UserWallet;
            direction: Direction;
            initiationType: ContractTransactionType;
            currencyName: string;
            currencySymbol: string;
            decimals: number;
            label: string;
            image?: Wallets.Images;
            hasScamTokens: boolean;
        };
        followupTxns?: TransactionHistory[];
        stuckByTxnId?: string;
        confirmTxnId?: string;
        scamTokens?: Array<TransactionToken>;
        context?: Transactions.Context;
    }
}
//# sourceMappingURL=transactions.d.ts.map