export declare namespace Wallets {
    export interface Wallet {
        _id: string;
        name: string;
        address: string;
        addressRegex?: string;
        alternativeAddress?: string;
        alternativeAddressRegex?: string;
        externalWalletId?: string;
        externalCurrencyId?: string;
        balance: string;
        image?: Images;
        network?: Network;
        contractAddress?: string;
        assetRef?: string;
        security?: boolean;
        hidden?: boolean;
    }
    export interface RecommendedSwapToken {
        address: string;
        symbol: string;
        name: string;
        chainId: string;
        decimals: number;
        logoURI: number;
        _id: string;
        currencyId?: string;
        network?: string;
        enabled?: boolean;
        bip44?: number;
        contractAddress?: string;
        imageUrl: Images;
    }
    interface Bip44 {
        name: string;
        id: string;
        bip44: string;
        symbol: string;
    }
    export interface UserCurrency {
        externalCurrencyId?: string;
        currencyName: string;
        currencySymbol: string;
        tokenDecimals?: number;
        rpcUrl?: string;
        currency: string;
        balance: string;
        price: string;
        assetRef: string;
        wallets: Array<Wallet>;
        supportedChains?: Network[];
        details?: Details;
        decimals?: number;
        image?: Images;
        fiat?: number;
    }
    interface NftWallets {
        lastOwner: string;
        walletId: string;
        externalWalletId?: string;
        balance?: number;
    }
    export interface UserNFT {
        _id: string;
        instanceId: number;
        nft: NFT;
        attributes: Array<NFTAttribute>;
        metadata?: {
            image: string;
            attributes: Array<NFTAttribute>;
            name?: string;
            description?: string;
        };
        externalWalletId?: string;
        balance?: number;
        wallets: Array<NftWallets>;
    }
    export enum NFTTypes {
        'NFT' = "NFT",
        'SFT' = "SFT"
    }
    export interface Details {
        name: string;
        symbol: string;
        bip44: Bip44;
        coingecko?: {
            image: Images;
        };
        basic?: {
            currencyBIP44: string;
        };
    }
    export interface UserWallet extends Wallet {
        currencyName: string;
        currencySymbol: string;
        price: string;
        assetRef: string;
        tokens?: Token[];
        type?: 'external' | 'internal' | 'aag';
        nftBalance?: number;
        fiat?: number;
        security?: boolean;
        hidden?: boolean;
    }
    export interface Images {
        thumb: string;
        small: string;
        large: string;
    }
    export interface Network {
        chainId: string;
        currency?: string;
        name?: string;
        externalCurrencyId?: string;
        rpcUrl?: string;
        image?: Images;
        recent?: boolean;
        autoCreate?: boolean;
        enabled?: boolean;
        network?: string;
        alchemyNetwork: string;
    }
    export interface Token {
        currencyName?: string;
        currencySymbol?: string;
        tokenDecimals: number;
        price?: string;
        assetRef: string;
        externalWalletId?: string;
        externalCurrencyId: string;
        balance: string;
        contractAddress: string;
        image: Images;
    }
    export interface NFTAttribute {
        trait_type: string;
        value: string;
    }
    export interface NFT {
        _id: string;
        contractAddress: string;
        name: string;
        symbol: string;
        tokenURI: string;
        metadata?: {
            image: string;
            attributes: Array<NFTAttribute>;
        };
        chainId: string;
        bip44: string;
        type: 'ERC721' | 'ERC1155';
        generalType: NFTTypes;
        balance: number;
        from?: string;
        to?: string;
    }
    export interface ContactWalletAddress {
        id: string;
        name: string;
        address: string;
    }
    export interface Contact {
        id?: string;
        name: string;
        photo?: string;
        wallets: ContactWalletAddress[];
    }
    export {};
}
//# sourceMappingURL=wallets.d.ts.map